﻿using Infragistics.Controls.Editors.Primitives;
using Infragistics.Windows.Editors;
using System;
using System.Diagnostics;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;

namespace Tabbehavior_SampleApp
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			var test = new Test();
			mGrid.SelectedObject = test;
		}

		private class Test
		{
			public string Test1 { get; set; } = "Test1Value";
			public string Test2 { get; set; } = "Test2Value";
		}
        
        private void StackPanel_PreviewGotKeyboardFocus(object sender, System.Windows.Input.KeyboardFocusChangedEventArgs e)
        {
            Debug.WriteLine("PREVIEW KEYBOARD FOCUS");
            StackPanel panel = sender as StackPanel;

            XamTextEditor editor = panel.Children[0] as XamTextEditor;

            panel.PreviewGotKeyboardFocus -= StackPanel_PreviewGotKeyboardFocus;
            editor.Focus();
            panel.PreviewGotKeyboardFocus += StackPanel_PreviewGotKeyboardFocus;
            e.Handled = true;
        }                    

        private void XamTextEditor_EditModeStarted(object sender, Infragistics.Windows.Editors.Events.EditModeStartedEventArgs e)
        {
            Debug.WriteLine("EDIT MODE STARTED");

			XamTextEditor editor = sender as XamTextEditor;
			editor.SelectAll();

            StackPanel panel = editor.Parent as StackPanel;
            if (panel != null)
            {
                panel.Focusable = false;
            }
        }

        private void XamTextEditor_EditModeEnded(object sender, Infragistics.Windows.Editors.Events.EditModeEndedEventArgs e)
        {
            Debug.WriteLine("EDIT MODE ENDED");

            XamTextEditor editor = sender as XamTextEditor;
            StackPanel panel = editor.Parent as StackPanel;
            if (panel != null)
            {
                panel.Focusable = true;
            }
        }

        private void mGrid_PreviewKeyDown(object sender, KeyEventArgs e)
        {
            if(e.Key == Key.LeftShift)
            {
                var x = Keyboard.FocusedElement;

                if(x is PropertyGridPropertyItemView)
                {
                    PropertyGridPropertyItemView view = x as PropertyGridPropertyItemView;
                    
                    if(view.EditorElement is StackPanel)
                    {
                        StackPanel panel = view.EditorElement as StackPanel;
                        panel.Focusable = false;
                    }
                }
            }
        }

        private void mGrid_PreviewKeyUp(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.LeftShift)
            {
                var x = Keyboard.FocusedElement;

                if (x is PropertyGridPropertyItemView)
                {
                    PropertyGridPropertyItemView view = x as PropertyGridPropertyItemView;

                    if (view.EditorElement is StackPanel)
                    {
                        StackPanel panel = view.EditorElement as StackPanel;
                        panel.Focusable = true;
                    }
                }                
            }
        }

        private void PropertyGridPropertyItemView_PreviewLostKeyboardFocus(object sender, KeyboardFocusChangedEventArgs e)
        {
            PropertyGridPropertyItemView view = sender as PropertyGridPropertyItemView;
            if(view.EditorElement is StackPanel)
            {
                StackPanel panel = view.EditorElement as StackPanel;
                panel.Focusable = true;
            }
        }
    }
}
